<?php
/*
Plugin Name: ریدایرکت بر اساس آیپی کشور
Description: تغییر مسیر WPML بر اساس IP کشور به طور خودکار کشور بازدید کننده شما را شناسایی می کند و به زبان آنها هدایت می شود.
Version: 2.4
Author: نوین وردپرس
Author URI: http://wpnovin.com
License: GPLv2 or later
*/
namespace CrivionAtEnvato;

// load classes
require_once __DIR__ . '/code/IP.class.php';
require_once __DIR__ . '/code/GeoIP.class.php';
require_once __DIR__ . '/code/Popup.class.php';
require_once __DIR__ . '/vendor/autoload.php';


update_option('wpmladr-functionality', 'Yes');


class WPML_AutoDetectRedirect_by_IP {

	public static $plugin_dir;
	public static $option_name;
	public static $plugin_dir_url;
	public static $visitorIPAddress;
	public static $visitorCountry;
	public $plugin_permalink;
	public $reader;

	public function __construct() {
		
		// set plugin dir & url
		self::$plugin_dir = plugin_dir_path( __FILE__ );
		self::$plugin_dir_url = plugin_dir_url( __FILE__ );

		// set plugin permalink
		$this->plugin_permalink = 'wpml-detect-redirect-by-ip';

		// set mappings option name
		self::$option_name = 'crivion-wpml-autodetect-mappings';

		try {
			// set maxmind reader
			$reader = new \GeoIp2\Database\Reader( plugin_dir_path(__FILE__) . '/GeoLite2-Country/GeoLite2-Country.mmdb');

			// get & set user country
			self::$visitorIPAddress = \CrivionAtEnvato\IP::get();
			$record = $reader->country( self::$visitorIPAddress );
			self::$visitorCountry = $record->country->isoCode;
			
		} catch ( \Exception $e ) {

			self::$visitorCountry = 'N/A';

		}
		
		// add administration menu
 		add_action( 'admin_menu', array( $this, 'menu' ));

 		// add link to dashboard in plugins overview
 		$plugin_basename = plugin_basename(__FILE__); 
		add_filter("plugin_action_links_$plugin_basename", array( $this, 'settings_link' ) );

		// plugin assets ( JS / CSS )
 		add_action( 'wp_enqueue_scripts', array( $this, 'assets' ));
 		add_action( 'admin_enqueue_scripts', array( $this, 'assets' ));


 		// the core: show popup with language suggestion based on user country
 		add_action('wp_head', array( '\CrivionAtEnvato\Popup', 'detectCountry' ) );

 		// add session support ( if not enabled already )
 		add_action( 'init', array( $this, 'start_session' ));

 		// register ajax hooks ( for session setting )
 		add_action( 'wp_ajax_wpmlAutoDetectRedirect', array( $this, 'set_session' ));
 		add_action( 'wp_ajax_nopriv_wpmlAutoDetectRedirect', array( $this, 'set_session' ));

	}

	// load plugin assets ( JS/CSS )
	public function assets(  ) {
			
			// require jQuery
			wp_enqueue_script('jquery');

		    // include sweetalert ( notification messages )
			wp_register_script( 'wpml-detect-redirect-sweetAlert', self::$plugin_dir_url. 'static/sweetalert.min.js', false, '1.0.0' );
			wp_enqueue_script( 'wpml-detect-redirect-sweetAlert' );

			// include chosenJS
			wp_register_script( 'wpml-detect-redirect-chosen', self::$plugin_dir_url. 'static/chosen.jquery.min.js', false, '1.0.0' );
			wp_enqueue_script( 'wpml-detect-redirect-chosen' );

			// include jsColor
			wp_register_script( 'wpml-detect-redirect-jscolor', self::$plugin_dir_url. 'static/jscolor.min.js', false, '1.0.0' );
			wp_enqueue_script( 'wpml-detect-redirect-jscolor' );

		    // require plugin AJAX
			wp_register_script( 'wpml-detect-redirect-JS', plugin_dir_url(__FILE__) . 'static/wpml-auto-detect-redirect.js', false, '1.0.0' );
    		wp_enqueue_script( 'wpml-detect-redirect-JS' );

			// make sure ajax-url is defined
			wp_localize_script( 'wpml-detect-redirect-JS', 'wpmldetectredirectajax', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );

			// include plugin styles
			wp_register_style( 'wpml-detect-redirect-chosen', plugin_dir_url(__FILE__) . 'static/chosen.min.css', false, '1.0.0' );
			wp_enqueue_style( 'wpml-detect-redirect-chosen' );

			wp_register_style( 'wpml-detect-redirect-sweetalert', plugin_dir_url(__FILE__) . 'static/sweetalert.css', false, '1.0.0' );
			wp_enqueue_style( 'wpml-detect-redirect-sweetalert' );

			$cancelButtonColor = get_option('wpml-autoredirect-cancel-color', 'C1C1C1');
			echo '<style>.sweet-alert button.cancel { background: #'.$cancelButtonColor.' !important; }</style>';

	}

	// start session
	public function start_session() {
	    if(!session_id()) {
			@ob_start();
	        @session_start();
	    }
	}

	// set session to avoid opening modal if "no, thanks" was clicked
	public function set_session( ) {
	
		if( isset( $_POST[ 'set' ] ) ) {
		
			// keep session to avoid asking again for a few time
			$_SESSION[ 'wpml-audotect-redirect-session' ] = date( 'jS F Y H:i' ) . ':' . self::$visitorIPAddress . ':' . self::$visitorCountry;
		}

		die( "" );
	}

	public function dashboard(  ) {

		if( !function_exists( 'icl_get_languages' ) ) {
			echo self::message('Sorry, it appears that you do NOT have WPML installed! <br />This plugin is specifically built for WPML as an Addon.');
			return;
		}

		// functionality
		if( 'Yes' != get_option( 'wpmladr-functionality', 'No' ) ) {
			echo '<script>window.location.href="'.admin_url('admin.php?page=wpml-adrlic-settings').'";</script>';
			exit;
		}

		// wpml languages
		$wpml_langs = icl_get_languages('skip_missing=N&orderby=KEY&order=DIR&link_empty_to=str');

		// get country list for dropdown
	    $geoIP = new \CrivionAtEnvato\GeoIP;
	    $countryList = array_combine($geoIP->GEOIP_COUNTRY_CODES, $geoIP->GEOIP_COUNTRY_NAMES);
	    asort($countryList);
	    $countryList = array_filter($countryList);

	    // get current mappings
	    $current_mappings = get_option( self::$option_name ); 

	    // if remove
	    if( isset( $_GET[ 'delete' ] )) {
	    	$country = trim(strip_tags( $_GET[ 'delete' ] ));

	    	if( isset( $current_mappings[ $country ] ) ) {
	    		unset( $current_mappings[ $country ] );
	    		update_option( self::$option_name, $current_mappings );
	    	}

	    }

		// process mapping
		if( isset( $_POST[ 'sbWPMLMapping' ] ) ) {
			if( isset( $_POST[ 'wpml-autodetect-language' ] ) AND 
			    isset( $_POST[ 'wpml-autodetect-country' ] ) ) {

				// trim/strip
				$lang_code    = trim(strip_tags($_POST[ 'wpml-autodetect-language' ]));
				$lang_country = trim(strip_tags($_POST[ 'wpml-autodetect-country' ]));

				// set new mappings array
				$new_mappings = array( $lang_country => $lang_code );

				// if option already exists merge, else create new option with only this array
				if( $current_mappings = get_option( self::$option_name ) ) {

					// merge current mappings with new mappings
					$new_mappings = array_merge( $new_mappings, $current_mappings );
					update_option( self::$option_name, $new_mappings );

				}else{
					update_option( self::$option_name, $new_mappings );
				}

				// update current mappings (for the overview)
				$current_mappings = $new_mappings;

			}
		}

		// include mappings overview
		require_once self::$plugin_dir . 'views/mappings.overview.php';

		// include create new mapping
		require_once self::$plugin_dir . 'views/mappings.create.php';

		// close </div> (id=#wrap)
		echo self::wrap();
	}

	// settings
	public function settings(  ) {
		
		$message = '';

		// process button color updates
		if( isset( $_POST[ 'sbWPMLColors' ] ) ) {
			update_option( 'wpml-autoredirect-confirm-color', trim( strip_tags( $_POST[ 'wpml-autoredirect-confirm-color' ] ) ) );
			update_option( 'wpml-autoredirect-cancel-color', trim( strip_tags( $_POST[ 'wpml-autoredirect-cancel-color' ] ) ) );

			$message = self::message('Button colors successfully saved.');

		}

		// process action type ( popup or redirect )
		if( isset( $_POST[ 'sbWPMLAction' ] ) ) {
			$message = self::message('Action type successfully saved.');
			update_option( 'wpml-autodetect-action', $_POST[ 'wpml-autodetect-action' ] );
		}

		// process settings updates ( texts & titles )
		if( isset( $_POST[ 'sbWPMLSettings' ] ) ) {
			unset( $_POST[ 'sbWPMLSettings' ] );

			foreach( $_POST as $k => $v ) {
				if( is_string($k) AND (stristr( $k, 'crv-wpml' ) !== FALSE) )
					update_option( $k, trim( strip_tags( $v ) ) );
			}

			$message = self::message('Changes successfully saved.');

		}

		require_once self::$plugin_dir . 'views/settings.php';

	}

	// create HTML wrap structure
 	public static function wrap( $type = 'footer', $title = '' ) {

		if( $type == 'header' ) {
			$return = '<div class="wrap">';
			$return .= sprintf( '<h2>%s</h2><hr/>', $title );

		}elseif( $type == 'footer' ) {
			$return = '</div>';
		}

		return $return;
	}

	// a message div 
	public static function message( $message ) {
		return '<div class="updated below-h2">' . $message . '</div>';
	}

	// icon 
	public static function flag_icon( $width = 18, $height = 18 ) {
		// return the icon
		return '<img src="'.plugin_dir_url(__FILE__).'/static/ontarget.svg" width="'.$width.'" height="'.$height.'" />';
	}

	// add settings link ( in plugins dashboard )
	public function settings_link( $links ) { 

	  $url = admin_url( 'admin.php?page=' . $this->plugin_permalink );
	  $settings_link = '<a href="'.$url.'">داشبورد</a>'; 
	  $mylinks = array( $settings_link );

	  return array_merge( $links, $mylinks ); 
	}

	// translate popup texts instructions
	public function translate_popup(  ) {
		require_once self::$plugin_dir . 'views/translate-instructions.php';
	}

	// plugin functionality
	public function functionality(  ) {

		$license_msg = '';

		if( isset( $_POST[ 'purchase_code' ] ) ) {
			$license_msg = $this->wpgeoip_ajax_autoupdate( $_POST[ 'purchase_code' ] );
		}

		require_once self::$plugin_dir . 'views/functionality.php';	
	}

	// validate functionality
	public function wpgeoip_ajax_autoupdate( $purchase_code ) {

		$blogURL = get_bloginfo('url');
		$url = 'http://crivion.com/envato-licensing/index.php';

		if(!isset($purchase_code) OR empty($purchase_code)) 
			return '<div class="updated below-h2 updated-red">License code required</div>';

		//open connection
		$ch = curl_init();

		//set the url, number of POST vars, POST data
		curl_setopt($ch,CURLOPT_URL, $url);
		curl_setopt($ch,CURLOPT_POST, 2);
		curl_setopt($ch,CURLOPT_RETURNTRANSFER,1);
		curl_setopt($ch,CURLOPT_POSTFIELDS, 'product=WPML_AutoDetectRedirect_by_IP&license_code=' . $purchase_code . '&blogURL=' . $blogURL);
		curl_setopt($ch,CURLOPT_USERAGENT, 'crivion/envato-license-checker-v1.0');

		//execute post
		$result = curl_exec($ch);

		//close connection
		curl_close($ch);

		//if LICENSE_VALID_AUTOUPDATE_ENABLED
		if( $result == 'LICENSE_VALID_AUTOUPDATE_ENABLED' ) {

			update_option('wpmladr-functionality', 'Yes');

			return '<div class="updated below-h2 updated-red">Congratulations! You have activated functionality of this plugin.</div>';
		}else{
			return '<div class="updated below-h2 updated-red">' . $result . '</div>';
		}

	}


	// plugin WP-admin menu
 	public function menu() {

 		// main pages : dashboard
 		add_menu_page( 'ریدایرکت براساس IP', 'ریدایرکت براساس IP', 'publish_pages', $this->plugin_permalink, array( $this, 'dashboard' ), plugin_dir_url(__FILE__) . 'static/ontarget.svg' );
		add_submenu_page( $this->plugin_permalink, 'ریدایرکت براساس IP', 'داشبورد', 'publish_pages', $this->plugin_permalink, array( $this, 'dashboard' ));

		// configuration page 
		add_submenu_page( $this->plugin_permalink, 'تنظیمات', 'تنظیمات', 'publish_pages', 'wpml-dr-settings', array( $this, 'settings' ));

		// translate instructions page
		add_submenu_page( $this->plugin_permalink, 'ترجمه پاپ آپ', 'ترجمه پاپ آپ', 'publish_pages', 'wpml-dr-translate-popup', array( $this, 'translate_popup' ));		

 	}


}

new \CrivionAtEnvato\WPML_AutoDetectRedirect_by_IP;